Structs
- Provides a reliable cache for HashMap<Key, Value> where value can be derived from key, but could be expensive to generate. The cache is thread safe and can be used in multi-threaded environment. The cache is not async, so it is not suitable for async environment. For async cache, use CasheAsync instead.